pub struct CallDependencySummary {
pub callee: Option<DefId>,
pub name: String,
pub return_depends_on_args: Vec<usize>,
pub may_write_args: Vec<usize>,
pub unsupported: bool,
}Expand description
Dependency summary consumed by the backward visitor.
Fields
callee: Option<DefId>Callee definition when the call target is statically known.
name: StringHuman-readable callee name.
return_depends_on_args: Vec<usize>If the call destination is relevant, these call arguments are relevant.
may_write_args: Vec<usize>Arguments that may be written or invalidated by the call.
unsupported: boolTrue when this summary is conservative rather than precise.
Implementations